@@ -545,18 +545,6 @@ const sourceToPipelineCopyTemplate = `{{- define "sourceToPipelineCopyTemplate"
       @type relabel
       @label {{labelName $pipelineLabel}}
     </store>
-{{- end }}
-{{ if .IncludeLegacySecureForward }}
-    <store>
-      @type relabel
-      @label @_LEGACY_SECUREFORWARD
-    </store>
-{{- end }}
-{{ if .IncludeLegacySyslog }}
-    <store>
-      @type relabel
-      @label @_LEGACY_SYSLOG
-    </store>
 {{- end }}
   </match>
 </label>
