@@ -17,7 +17,7 @@ import (
 	"k8s.io/apimachinery/pkg/util/wait"
 
 	"github.com/openshift/cluster-logging-operator/pkg/k8shandler"
-	"github.com/openshift/cluster-logging-operator/pkg/logger"
+	clolog "github.com/ViaQ/logerr/log"
 	"github.com/openshift/cluster-logging-operator/pkg/utils"
 )
 
@@ -158,12 +158,12 @@ func (syslog *syslogReceiverLogStore) hasLogs(file string, timeToWait time.Durat
 	err = wait.Poll(defaultRetryInterval, timeToWait, func() (done bool, err error) {
 		output, err := syslog.tc.PodExec(OpenshiftLoggingNS, podName, "syslog-receiver", []string{"bash", "-c", cmd})
 		if err != nil {
-			logger.Errorf("failed to fetch logs from syslog-receiver %v", err)
+			clolog.Error(err,"failed to fetch logs from syslog-receiver")
 			return false, nil
 		}
 		value, err := strconv.Atoi(strings.TrimSpace(output))
 		if err != nil {
-			logger.Debugf("Error parsing output: %s", output)
+			clolog.V(2).Error(err,"Error parsing output","output", output)
 			return false, nil
 		}
 		return value > 0, nil
@@ -186,15 +186,15 @@ func (syslog *syslogReceiverLogStore) grepLogs(expr string, logfile string, time
 	if len(pods.Items) == 0 {
 		return NotFound, errors.New("No pods found for syslog receiver")
 	}
-	logger.Debugf("Pod %s", pods.Items[0].Name)
+	clolog.V(3).Info("Pod", "PodName", pods.Items[0].Name)
 	cmd := fmt.Sprintf(expr, logfile)
-	logger.Debugf("running expression %s", cmd)
+	clolog.V(3).Info("running expression", "expression", cmd)
 	var value string
 
 	err = wait.Poll(defaultRetryInterval, timeToWait, func() (bool, error) {
 		output, err := syslog.tc.PodExec(OpenshiftLoggingNS, pods.Items[0].Name, "syslog-receiver", []string{"bash", "-c", cmd})
 		if err != nil {
-			logger.Errorf("failed to fetch logs from syslog-receiver %v", err)
+			clolog.Error(err, "failed to fetch logs from syslog-receiver")
 			return false, nil
 		}
 		value = strings.TrimSpace(output)
@@ -466,7 +466,7 @@ func (tc *E2ETestFramework) DeploySyslogReceiver(testDir string, protocol corev1
 
 func (tc *E2ETestFramework) CreateSyslogReceiverSecrets(testDir, logStoreName, secretName string) (*corev1.Secret, error) {
 	workingDir := fmt.Sprintf("/tmp/clo-test-%d", rand.Intn(10000))
-	logger.Debugf("Generating Pipeline certificates for %q to %s", "rsyslog-receiver", workingDir)
+	clolog.V(3).Info("Generating Pipeline certificates for", "rsyslog-receiver", workingDir)
 	if _, err := os.Stat(workingDir); os.IsNotExist(err) {
 		if err = os.MkdirAll(workingDir, 0766); err != nil {
 			return nil, err
@@ -476,13 +476,17 @@ func (tc *E2ETestFramework) CreateSyslogReceiverSecrets(testDir, logStoreName, s
 		return nil, err
 	}
 	script := fmt.Sprintf("%s/syslog_cert_generation.sh", testDir)
-	logger.Debugf("Running script '%s %s %s %s'", script, workingDir, OpenshiftLoggingNS, logStoreName)
+	clolog.Info("Running script '%s %s %s %s'", "script",script, "workingdir",workingDir, "namespace", OpenshiftLoggingNS, "logStore", logStoreName)
 	cmd := exec.Command(script, workingDir, OpenshiftLoggingNS, logStoreName)
 	result, err := cmd.Output()
-	if logger.IsDebugEnabled() {
-		logger.Debugf("cert_generation output: %s", string(result))
-		logger.Debugf("err: %v", err)
+
+	if clolog.V(3).Enabled() {
+		clolog.V(3).Info("cert_generation :", "output", string(result))
 	}
+	if err != nil {
+		clolog.V(3).Error(err, "Error:")
+	}
+
 	data := map[string][]byte{
 		"tls.key":       utils.GetWorkingDirFileContents("syslog-server.key"),
 		"tls.crt":       utils.GetWorkingDirFileContents("syslog-server.crt"),
@@ -496,7 +500,7 @@ func (tc *E2ETestFramework) CreateSyslogReceiverSecrets(testDir, logStoreName, s
 		OpenshiftLoggingNS,
 		data,
 	)
-	logger.Debugf("Creating secret %s for logStore %s", secret.Name, logStoreName)
+	clolog.V(3).Info("Creating secret for logStore", "secret", secret.Name, "logStore", logStoreName)
 	if secret, err = tc.KubeClient.CoreV1().Secrets(OpenshiftLoggingNS).Create(context.TODO(), secret, sOpts); err != nil {
 		return nil, err
 	}
